altius_py package — altius_py documentation

# altius_py package

## Submodules

## altius_py.altius_py module

A Python module implemented in Rust.

altius_py.altius_py.load()

altius_py.altius_py.session()

## Module contents

class altius_py.InferenceSession(model_path)

  Bases: `object`

  `InferenceSession` is the class used to run a model.

  run(output, input)

    Compute the predictions.

    Parameters

      - output (Optional[list[str]]) – Name of the outputs, but must be None for now.

      - input (dict[str, numpy.ndarray]) – Dictionary `{ input_name: input_value }`.

    Returns

      Output values.

    Return type

      list[numpy.ndarray]